@@ -27,6 +27,9 @@ class SessionData;
 class IdentityInfo;
 }
 
+namespace KAccounts
+{
+
 /**
  * @brief Create a new account for the specified provider
  */
@@ -53,6 +56,7 @@ private Q_SLOTS:
     void pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &map);
     void pluginError(const QString &error);
     void pluginCancelled();
+    void startAuthSession(const QVariantMap &data);
 
 Q_SIGNALS:
     void providerNameChanged();
@@ -68,4 +72,7 @@ private:
     SignOn::Identity *m_identity = nullptr;
     bool m_done = false;
 };
+
+};
+
 #endif // CREATE_ACCOUNT_JOB_H
